@@ -2,10 +2,10 @@
 
 
 # continuous
-#	  points
-#	  smooth
-#	  density
-#	  cor
+#    points
+#    smooth
+#    density
+#    cor
 #   blank
 
 # combo
@@ -58,6 +58,7 @@
 #' chosen as an option, then ggpairs will produce a blank plot, as if nothing was 
 #' printed there.  
 #' 
+#' @export
 #' @param data data set using.  Can have both numerical and categorical data.
 #' @param columns which columns are used to make plots.  Defaults to all columns.
 #' @param title title for the graph
@@ -66,8 +67,9 @@
 #' @param diag see Details
 #' @param params vector of parameters to be applied to geoms.  Each value must have a corresponding name, such as \code{c(binwidth = 0.1)}.
 #' @param ... other parameters being supplied to geom's aes, such as color
+#' @param axisLabels either "internal" for labels in the diagonal plots, "none" for no axis labels, or "show" to display axisLabels
+#' @param legends boolean to determine the printing of the legend in each plot. Not recommended.
 #' @param verbose boolean to determine the printing of "Plot #1, Plot #2...."
-#' @param axisLabels either "internal" for labels in the diagonal plots, or "none" for no axis labels
 #' @keywords hplot
 #' @author Barret Schloerke \email{schloerke@@gmail.com}, Jason Crowley \email{crowley.jason.s@@gmail.com}, Di Cook \email{dicook@@iastate.edu}, Heike Hofmann \email{hofmann@@iastate.edu}, Hadley Wickham \email{h.wickham@@gmail.com}
 #' @return ggpair object that if called, will print
@@ -81,10 +83,10 @@
 #'
 #' # Custom Example
 #' ggpairs(
-#' 	iris[,3:5], 
-#' 	upper = list(continuous = "density", combo = "box"), 
-#' 	lower = list(continuous = "points", combo = "dot"), 
-#' 	diag = list(continuous = "bar", discrete = "bar")
+#'   iris[,3:5], 
+#'   upper = list(continuous = "density", combo = "box"), 
+#'   lower = list(continuous = "points", combo = "dot"), 
+#'   diag = list(continuous = "bar", discrete = "bar")
 #' )
 #'
 #'
@@ -92,10 +94,10 @@
 #' diamonds.samp <- diamonds[sample(1:dim(diamonds)[1],200),]
 #'
 #' # Custom Example
-#' diamondMatrix <- ggpairs(	
-#'  diamonds.samp[,1:3], 	
-#'  upper = list(continuous = "density", combo = "box"), 	
-#'  lower = list(continuous = "points", combo = "dot"), 	
+#' diamondMatrix <- ggpairs(  
+#'  diamonds.samp[,1:3],   
+#'  upper = list(continuous = "density", combo = "box"),   
+#'  lower = list(continuous = "points", combo = "dot"),   
 #'  diag = list(continuous = "bar", discrete = "bar"), 
 #'  color = "cut", 
 #'  title = "Diamonds"
@@ -105,10 +107,10 @@
 #'
 #' # Will plot four "Incorrect Plots"
 #' bad_plots <- ggpairs(
-#' 	iris[,3:4],
-#' 	upper = list(continuous = "wrongType1", combo = "wrongType2"),
-#' 	lower = list(continuous = "IDK1", combo = "IDK2", discrete = "mosaic"),
-#' 	diag = list(continuous = "points", discrete = "box")
+#'   iris[,3:4],
+#'   upper = list(continuous = "wrongType1", combo = "wrongType2"),
+#'   lower = list(continuous = "IDK1", combo = "IDK2", discrete = "mosaic"),
+#'   diag = list(continuous = "points", discrete = "box")
 #' )
 #' #bad_plots
 #'
@@ -201,263 +203,268 @@ ggpairs <- function(
   diag = list(),
   params = NULL,
   ...,
-  verbose = FALSE,
-  axisLabels = "internal"
+  axisLabels = "internal",
+  legends = FALSE,
+  verbose = FALSE
 ){
   require(ggplot2)
-  removeTicks <- TRUE
   printInfo <- FALSE
 
-	verbose = verbose || printInfo
-	
-	
-	if(!is.list(upper) && upper == "blank"){
-		upper <- list()
-		upper$continuous = "blank"
-		upper$combo = "blank"
-		upper$discrete = "blank"
-	}
-	if(!is.list(lower) && lower == "blank"){
-		lower <- list()
-		lower$continuous = "blank"
-		lower$combo = "blank"
-		lower$discrete = "blank"
-	}
-	if(!is.list(diag) && diag == "blank"){
-		diag <- list()
-		diag$continuous = "blank"
-		diag$discrete = "blank"
-	}
+  verbose = verbose || printInfo
 
-	if(!is.list(upper))
-		stop("upper is not a list")
-
-	if (is.null(upper$continuous)) {
-		upper$continuous <- "cor"
-	}
-	if (is.null(upper$combo)) {
-		upper$combo <- "facethist"
-	}
-	if (is.null(upper$discrete)) {
-		upper$discrete <- "facetbar"
-	}
-
-	if(!is.list(lower))
-		stop("lower is not a list")
-
-	if (is.null(lower$continuous)) {
-		lower$continuous <- "points"
-	}
-	if (is.null(lower$combo)) {
-		lower$combo <- "box"
-	}
-	if (is.null(lower$discrete)) {
-		lower$discrete <- "facetbar"
-	}
-
-	if (is.null(diag$continuous)) {
-		diag$continuous <- "density"
-	}
-	if (is.null(diag$discrete)) {
-		diag$discrete <- "bar"
-	}
-
-
-	data <- as.data.frame(data)
-      for ( i in 1:dim(data)[2] ) {
-        if(is.character(data[,i])) data[,i] <- as.factor(data[,i])
-      }
-	numCol <- length(columns)
-	if(printInfo)
-    cat("data col: ", numCol,"\n")
-
-	
-
-	ggpairsPlots <- list()
-	
-
-	grid <- rev(expand.grid(y = 1:ncol(data[columns]), x = 1:ncol(data[columns])))
-
-	all <- do.call("rbind", lapply(1:nrow(grid), function(i) {
-		xcol <- grid[i, "x"]
-		ycol <- grid[i, "y"]
-		data.frame(xvar = names(data[columns])[ycol], yvar = names(data[columns])[xcol])
-	}))
-
-  if(printInfo){cat("\n\n\nALL\n");print(all)}
-
-	dataTypes <- plot_types(data[columns])
-  if(printInfo){cat("\n\n\nDATA TYPES\n");print(dataTypes)}
-
-	if (identical(axisLabels,"internal")) {
-  	dataTypes$Type <- as.character(dataTypes$Type)
-  	dataTypes$Type[dataTypes$posx == dataTypes$posy] <- "label"
-  	dataTypes$Type <- as.factor(dataTypes$Type)
+  if (! axisLabels %in% c("none", "show", "internal")) {
+    warning("axisLabels not in c('none', 'show', 'internal').  Reverting to 'internal'")
+    axisLabels <- "internal"
   }
   
   
-	for(i in 1:nrow(dataTypes)){
-		p <- "blank"
-		type <- dataTypes[i,"Type"]
+  if(!is.list(upper) && upper == "blank"){
+    upper <- list()
+    upper$continuous = "blank"
+    upper$combo = "blank"
+    upper$discrete = "blank"
+  }
+  if(!is.list(lower) && lower == "blank"){
+    lower <- list()
+    lower$continuous = "blank"
+    lower$combo = "blank"
+    lower$discrete = "blank"
+  }
+  if(!is.list(diag) && diag == "blank"){
+    diag <- list()
+    diag$continuous = "blank"
+    diag$discrete = "blank"
+  }
 
-		posX <- as.numeric(as.character(dataTypes[i,"posx"]))
-		posY <- as.numeric(as.character(dataTypes[i,"posy"]))
-		xColName <- as.character(dataTypes[i,"xvar"])
-		yColName <- as.character(dataTypes[i,"yvar"])
-		
+  if(!is.list(upper))
+    stop("upper is not a list")
 
-		up <- posX > posY
-		
-  	if(printInfo) cat("Pos #", i, "\t(", posX, ",", posY, ")\t type: ")
+  if (is.null(upper$continuous)) {
+    upper$continuous <- "cor"
+  }
+  if (is.null(upper$combo)) {
+    upper$combo <- "facethist"
+  }
+  if (is.null(upper$discrete)) {
+    upper$discrete <- "facetbar"
+  }
 
-		section_aes <- section_params <- NULL
+  if(!is.list(lower))
+    stop("lower is not a list")
 
-		if(type == "scatterplot"){
-			if(printInfo) cat("scatterplot\n")
-			
-			subType <- "points"
-			if(up){
-				subType <- upper$continuous
-				section_aes <- upper$aes_string
-				section_params <- upper$params
-			} else {
-				subType <- lower$continuous
-				section_aes <- lower$aes_string
-				section_params <- lower$params
-			}
-			
-			combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
-			if(subType == "density") {
-				combo_aes <- addAndOverwriteAes(combo_aes, aes_string(group = combo_aes$colour))
-				combo_aes
-			}
-				
-			combo_params <- addAndOverwriteAes(params, section_params)
-				
-				
-				p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
-#			else if(subType == "smooth")
-#				p <- ggally_smooth(data, combo_aes, params)
-#			else if(subType == "density")
-#  				p <- ggally_density(data, combo_aes, params )
-#			else if(subType == "cor")
-#				p <- ggally_cor(data, combo_aes, params)
-#			else if(subType == "blank")
-#				p <- ggally_blank()
-		
-		} else if(type == "box-hori" || type == "box-vert"){
-  		if(printInfo)cat("box-hori-vert\n")
+  if (is.null(lower$continuous)) {
+    lower$continuous <- "points"
+  }
+  if (is.null(lower$combo)) {
+    lower$combo <- "box"
+  }
+  if (is.null(lower$discrete)) {
+    lower$discrete <- "facetbar"
+  }
 
-			subType <- "box"
-			section_aes <- NULL
-			if(up){
-				subType <- upper$combo
-				section_aes <- upper$aes_string
-				section_params <- upper$params
-			} else {
-				subType <- lower$combo
-				section_aes <- lower$aes_string
-				section_params <- lower$params
-			}
-			combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
-			if(subType != "dot")
-				combo_aes <- mapping_color_fill(combo_aes)
-			combo_params <- addAndOverwriteAes(params, section_params)
+  if (is.null(diag$continuous)) {
+    diag$continuous <- "density"
+  }
+  if (is.null(diag$discrete)) {
+    diag$discrete <- "bar"
+  }
 
-			p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
-#			if(subType == "box")
-#				p <- ggally_box(data, combo_aes, params)
-#			else if(subType == "dot")
-#				p <- ggally_dot(data, combo_aes, params)
-#			else if(subType == "facethist")
-#				p <- ggally_facethist(data, combo_aes, params)
-#			else if(subType == "facetdensity")
-#				p <- ggally_facetdensity(data, combo_aes, params)
-#			else if(subType == "denstrip")
-#				p <- ggally_denstrip(data, combo_aes, params)
-#			else if(subType == "blank")
-#				p <- ggally_blank()
-				
-		} else if(type == "mosaic"){
-  		if(printInfo)cat("mosaic\n")
-		  
-			subType <- "facetbar"
-			section_aes <- NULL
-			if(up){
-				subType <- upper$discrete
-				section_aes <- upper$aes_string
-				section_params <- upper$params
-			} else {
-				subType <- lower$discrete
-				section_aes <- lower$aes_string
-				section_params <- lower$params
-			}
-			
-			combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
-			combo_params <- addAndOverwriteAes(params, section_params)
-			
-			if(subType == "ratio")
-				p <- ggally_ratio(data[, c(yColName, xColName)])
-			else if(subType == "facetbar"){
-				if(!is.null(combo_aes$colour)){
-					combo_aes <- addAndOverwriteAes(combo_aes, aes_string(fill = combo_aes$colour))
-				}
-				p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
-			}
-			# else if(subType == "blank")
-			# 	p <- "ggally_blank('blank')"
-                  else p <- ggally_text("Incorrect\nPlot",size=6)
 
-		} else if(type == "stat_bin-num"){
-  		if(printInfo)cat("stat_bin-num\n")
-		  
-			subType <- diag$continuous
-			
-			combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
-			if(subType != "density")
-				combo_aes <- mapping_color_fill(combo_aes)
+  data <- as.data.frame(data)
+      for ( i in 1:dim(data)[2] ) {
+        if(is.character(data[,i])) data[,i] <- as.factor(data[,i])
+      }
+  numCol <- length(columns)
+  if(printInfo)
+    cat("data col: ", numCol,"\n")
 
-			combo_params <- addAndOverwriteAes(params, diag$params)
-		
-			if(subType != "blank")
+  
+
+  ggpairsPlots <- list()
+  
+
+  grid <- rev(expand.grid(y = 1:ncol(data[columns]), x = 1:ncol(data[columns])))
+
+  all <- do.call("rbind", lapply(1:nrow(grid), function(i) {
+    xcol <- grid[i, "x"]
+    ycol <- grid[i, "y"]
+    data.frame(xvar = names(data[columns])[ycol], yvar = names(data[columns])[xcol])
+  }))
+
+  if(printInfo){cat("\n\n\nALL\n");print(all)}
+
+  dataTypes <- plot_types(data[columns])
+  if(printInfo){cat("\n\n\nDATA TYPES\n");print(dataTypes)}
+
+  if (identical(axisLabels,"internal")) {
+    dataTypes$Type <- as.character(dataTypes$Type)
+    dataTypes$Type[dataTypes$posx == dataTypes$posy] <- "label"
+    dataTypes$Type <- as.factor(dataTypes$Type)
+  }
+  
+  
+  for(i in 1:nrow(dataTypes)){
+    p <- "blank"
+    type <- dataTypes[i,"Type"]
+
+    posX <- as.numeric(as.character(dataTypes[i,"posx"]))
+    posY <- as.numeric(as.character(dataTypes[i,"posy"]))
+    xColName <- as.character(dataTypes[i,"xvar"])
+    yColName <- as.character(dataTypes[i,"yvar"])
+    
+
+    up <- posX > posY
+    
+    if(printInfo) cat("Pos #", i, "\t(", posX, ",", posY, ")\t type: ")
+
+    section_aes <- section_params <- NULL
+
+    if(type == "scatterplot"){
+      if(printInfo) cat("scatterplot\n")
+      
+      subType <- "points"
+      if(up){
+        subType <- upper$continuous
+        section_aes <- upper$aes_string
+        section_params <- upper$params
+      } else {
+        subType <- lower$continuous
+        section_aes <- lower$aes_string
+        section_params <- lower$params
+      }
+      
+      combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
+      if(subType == "density") {
+        combo_aes <- addAndOverwriteAes(combo_aes, aes_string(group = combo_aes$colour))
+        combo_aes
+      }
+        
+      combo_params <- addAndOverwriteAes(params, section_params)
+        
+        
+        p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
+#      else if(subType == "smooth")
+#        p <- ggally_smooth(data, combo_aes, params)
+#      else if(subType == "density")
+#          p <- ggally_density(data, combo_aes, params )
+#      else if(subType == "cor")
+#        p <- ggally_cor(data, combo_aes, params)
+#      else if(subType == "blank")
+#        p <- ggally_blank()
+    
+    } else if(type == "box-hori" || type == "box-vert"){
+      if(printInfo)cat("box-hori-vert\n")
+
+      subType <- "box"
+      section_aes <- NULL
+      if(up){
+        subType <- upper$combo
+        section_aes <- upper$aes_string
+        section_params <- upper$params
+      } else {
+        subType <- lower$combo
+        section_aes <- lower$aes_string
+        section_params <- lower$params
+      }
+      combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
+      if(subType != "dot")
+        combo_aes <- mapping_color_fill(combo_aes)
+      combo_params <- addAndOverwriteAes(params, section_params)
+
+      p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
+#      if(subType == "box")
+#        p <- ggally_box(data, combo_aes, params)
+#      else if(subType == "dot")
+#        p <- ggally_dot(data, combo_aes, params)
+#      else if(subType == "facethist")
+#        p <- ggally_facethist(data, combo_aes, params)
+#      else if(subType == "facetdensity")
+#        p <- ggally_facetdensity(data, combo_aes, params)
+#      else if(subType == "denstrip")
+#        p <- ggally_denstrip(data, combo_aes, params)
+#      else if(subType == "blank")
+#        p <- ggally_blank()
+        
+    } else if(type == "mosaic"){
+      if(printInfo)cat("mosaic\n")
+      
+      subType <- "facetbar"
+      section_aes <- NULL
+      if(up){
+        subType <- upper$discrete
+        section_aes <- upper$aes_string
+        section_params <- upper$params
+      } else {
+        subType <- lower$discrete
+        section_aes <- lower$aes_string
+        section_params <- lower$params
+      }
+      
+      combo_aes <- addAndOverwriteAes(aes_string(x = xColName, y = yColName, ...), section_aes)
+      combo_params <- addAndOverwriteAes(params, section_params)
+      
+      if(subType == "ratio")
+        p <- ggally_ratio(data[, c(yColName, xColName)])
+      else if(subType == "facetbar"){
+        if(!is.null(combo_aes$colour)){
+          combo_aes <- addAndOverwriteAes(combo_aes, aes_string(fill = combo_aes$colour))
+        }
+        p <- make_ggpair_text(subType, combo_aes, combo_params, printInfo)
+      }
+      else if(subType == "blank")
+        p <- "ggally_blank('blank')"
+      else p <- ggally_text("Incorrect\nPlot",size=6)
+
+    } else if(type == "stat_bin-num"){
+      if(printInfo)cat("stat_bin-num\n")
+      
+      subType <- diag$continuous
+      
+      combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
+      if(subType != "density")
+        combo_aes <- mapping_color_fill(combo_aes)
+
+      combo_params <- addAndOverwriteAes(params, diag$params)
+    
+      if(subType != "blank")
         p <- make_ggpair_text(paste(subType, "Diag", sep = "", collapse = ""), combo_aes, combo_params,printInfo)
-		  else
-		    p <- "blank"
-#			
-#				p <- ggally_densityDiag(data, combo_aes, params)
-#			else if(subType == "bar")
-#				p <- ggally_barDiag(data, combo_aes, params)
-#			else if(subType == "blank")
-#				p <- ggally_blank()
+      else
+        p <- "blank"
+#      
+#        p <- ggally_densityDiag(data, combo_aes, params)
+#      else if(subType == "bar")
+#        p <- ggally_barDiag(data, combo_aes, params)
+#      else if(subType == "blank")
+#        p <- ggally_blank()
 
-		} else if(type == "stat_bin-cat"){
-  		if(printInfo)cat("stat_bin-cat\n")
-  		
-			subType <- diag$discrete
-			combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
-			combo_aes <- mapping_color_fill(combo_aes)
-			
-			combo_params <- addAndOverwriteAes(params, diag$params)
+    } else if(type == "stat_bin-cat"){
+      if(printInfo)cat("stat_bin-cat\n")
+      
+      subType <- diag$discrete
+      combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
+      combo_aes <- mapping_color_fill(combo_aes)
+      
+      combo_params <- addAndOverwriteAes(params, diag$params)
 
-		
-			p <- make_ggpair_text(paste(subType, "Diag", sep = "", collapse = ""), combo_aes, combo_params, printInfo)
-#			if(subType == "bar")
-#				p <- ggally_barDiag(data, combo_aes, params)
-#			#else if(subType == "ratio")
-#			#	p <- ggally_ratio(dataSelect)
-#			else if(subType == "blank")
-#				p <- ggally_blank()
-		} else if(type == "label"){
-    	combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
+    
+      p <- make_ggpair_text(paste(subType, "Diag", sep = "", collapse = ""), combo_aes, combo_params, printInfo)
+#      if(subType == "bar")
+#        p <- ggally_barDiag(data, combo_aes, params)
+#      #else if(subType == "ratio")
+#      #  p <- ggally_ratio(dataSelect)
+#      else if(subType == "blank")
+#        p <- ggally_blank()
+    } else if(type == "label"){
+      combo_aes <- addAndOverwriteAes(aes_string(x = xColName, ...), diag$aes_string)
       combo_params <- addAndOverwriteAes(params, diag$params)
       
-    	p <- make_ggpair_text("diagAxis", combo_aes, combo_params, printInfo)
+      p <- make_ggpair_text("diagAxis", combo_aes, combo_params, printInfo)
     }
-		
-		ggpairsPlots[[length(ggpairsPlots)+1]] <- p
-		
-	}
-	
+    
+    ggpairsPlots[[length(ggpairsPlots)+1]] <- p
+    
+  }
+  
   plotMatrix <- list(
     data = data, 
     columns = columns, 
@@ -466,13 +473,12 @@ ggpairs <- function(
     verbose = verbose, 
     printInfo = printInfo,
     axisLabels = axisLabels,
-		removeTicks = removeTicks
+    legends = legends
   )
-	
-	attributes(plotMatrix)$class <- "ggpairs"
-	
-	plotMatrix
-	
+  
+  attributes(plotMatrix)$class <- "ggpairs"
+  
+  plotMatrix
 }
 
 #' Generate GGally Function Text
@@ -535,7 +541,7 @@ eval_ggpair <- function(txt, ggally_data) {
 #' @author Hadley Wickham \email{h.wickham@@gmail.com}
 # '
 vplayout <- function(x, y) {
-	viewport(layout.pos.row = x, layout.pos.col = y) 
+  viewport(layout.pos.row = x, layout.pos.col = y) 
 }
 
 
@@ -548,6 +554,7 @@ vplayout <- function(x, y) {
 #' @param columnFromLeft column from the left
 #' @keywords hplot
 #' @author Barret Schloerke \email{schloerke@@gmail.com}
+#' @export
 #' @examples
 #' plotMatrix <- ggpairs(mtcars[,c("mpg","wt","cyl")], upper = "blank", title = "Custom Example")
 #' # ggplot example taken from example(geom_text)
@@ -558,13 +565,13 @@ vplayout <- function(x, y) {
 #' plotMatrix
 putPlot <- function(plotMatrix, plotObj, rowFromTop, columnFromLeft){
 
-	pos <- columnFromLeft + (length(plotMatrix$columns)) * (rowFromTop - 1)
-	plotMatrix$plots[[pos]] <- plotObj
-	
-	if(plotMatrix$printInfo)
+  pos <- columnFromLeft + (length(plotMatrix$columns)) * (rowFromTop - 1)
+  plotMatrix$plots[[pos]] <- plotObj
+  
+  if(plotMatrix$printInfo)
     cat("\n\nDone placing plot: ",pos,"\n")
     
-	plotMatrix
+  plotMatrix
 }
 
 #' getPlot
@@ -575,6 +582,7 @@ putPlot <- function(plotMatrix, plotObj, rowFromTop, columnFromLeft){
 #' @param columnFromLeft column from the left
 #' @keywords hplot
 #' @author Barret Schloerke \email{schloerke@@gmail.com}
+#' @export
 #' @examples
 #' plotMatrix2 <- ggpairs(iris[,5:4], upper = list(combo = "denstrip"))
 #' getPlot(plotMatrix2, 1, 2)
@@ -582,18 +590,18 @@ getPlot <- function(plotMatrix, rowFromTop, columnFromLeft){
   if(plotMatrix$printInfo)
     cat("rowFromTop: ",rowFromTop," columnFromLeft: ",columnFromLeft,"\n")
   
-	pos <- columnFromLeft + (length(plotMatrix$columns)) * (rowFromTop - 1)
-	
+  pos <- columnFromLeft + (length(plotMatrix$columns)) * (rowFromTop - 1)
+  
   if(plotMatrix$printInfo) cat("Plot List Spot: ",pos,"\n")
   
   plot_text <- plotMatrix$plots[[pos]]
   if (is.character(plot_text)) {
-  	if (plot_text != "blank") {
-    	p <- eval_ggpair(plot_text, plotMatrix$data)
+    if (plot_text != "blank") {
+      p <- eval_ggpair(plot_text, plotMatrix$data)
       attributes( p)$class <- "ggplot"
     } else {
       p <- ggally_blank()
-  	}
+    }
   } else {
     p <- plot_text
   }
@@ -619,6 +627,7 @@ getPlot <- function(plotMatrix, rowFromTop, columnFromLeft){
 #' @method print ggpairs
 #' @keywords internal
 #' @author Barret Schloerke \email{schloerke@@gmail.com}
+#' @export
 #' @examples
 #'  ggpairs(iris[,3:5])
 print.ggpairs <- function(x, ...){
@@ -628,69 +637,69 @@ print.ggpairs <- function(x, ...){
   # variable names on the margins will not be used
   if(identical(plotObj$axisLabels,"internal")) {
     v1 <- viewport(
-#		x = unit(0.5, "npc") + unit(1,"lines"), 
-		y = unit(0.5, "npc") - unit(0.5,"lines"), 
-		width=unit(1, "npc") - unit(1,"lines"), 
-		height=unit(1, "npc") - unit(2, "lines")
-	)
+#    x = unit(0.5, "npc") + unit(1,"lines"), 
+    y = unit(0.5, "npc") - unit(0.5,"lines"), 
+    width=unit(1, "npc") - unit(1,"lines"), 
+    height=unit(1, "npc") - unit(2, "lines")
+  )
   } else {
-  	v1 <- viewport(
-#		x = unit(0.5, "npc") + unit(1,"lines"), 
-#		y = unit(0.5, "npc") + unit(1,"lines"), 
-		width=unit(1, "npc") - unit(3,"lines"), 
-		height=unit(1, "npc") - unit(3, "lines")
-	)
+    v1 <- viewport(
+#    x = unit(0.5, "npc") + unit(1,"lines"), 
+#    y = unit(0.5, "npc") + unit(1,"lines"), 
+    width=unit(1, "npc") - unit(3,"lines"), 
+    height=unit(1, "npc") - unit(3, "lines")
+  )
   }
   
   
-	numCol <- length(plotObj$columns)
+  numCol <- length(plotObj$columns)
 
-	v2 <- viewport(
-	     layout = grid.layout(
-	             numCol, 
-	             numCol, 
-	             widths = rep(1,numCol), 
-	             heights = rep(1,numCol) 
-	   ))
+  v2 <- viewport(
+       layout = grid.layout(
+               numCol, 
+               numCol, 
+               widths = rep(1,numCol), 
+               heights = rep(1,numCol) 
+     ))
 
-	grid.newpage()
-	
-	if(plotObj$title != ""){
-		pushViewport(viewport(height = unit(1,"npc") - unit(.4,"lines")))
-		grid.text(plotObj$title,x = .5, y = 1, just = c(.5,1),gp=gpar(fontsize=20))
-		popViewport()
-	}
+  grid.newpage()
+  
+  if(plotObj$title != ""){
+    pushViewport(viewport(height = unit(1,"npc") - unit(.4,"lines")))
+    grid.text(plotObj$title,x = .5, y = 1, just = c(.5,1),gp=gpar(fontsize=20))
+    popViewport()
+  }
 
   # This plots the variable names on the margins, which is not needed if using internal
 # axis labels
 if(!identical(plotObj$axisLabels,"internal")) {
-	# viewport for Left Names
-	pushViewport(viewport(width=unit(1, "npc") - unit(2,"lines"), height=unit(1, "npc") - unit(3, "lines")))
+  # viewport for Left Names
+  pushViewport(viewport(width=unit(1, "npc") - unit(2,"lines"), height=unit(1, "npc") - unit(3, "lines")))
 
-	pushViewport(viewport(layout = grid.layout(numCol, numCol, widths = rep(1,numCol), heights = rep(1,numCol) )))
+  pushViewport(viewport(layout = grid.layout(numCol, numCol, widths = rep(1,numCol), heights = rep(1,numCol) )))
 
-	# Left Side
-	for(i in 1:numCol){
-		grid.text(names(plotObj$data[,plotObj$columns])[i],0,0.5,rot=90,just=c("centre","centre"), vp = vplayout(as.numeric(i),1))
-	}
+  # Left Side
+  for(i in 1:numCol){
+    grid.text(names(plotObj$data[,plotObj$columns])[i],0,0.5,rot=90,just=c("centre","centre"), vp = vplayout(as.numeric(i),1))
+  }
 
 
-	popViewport()# layout
-	popViewport()# spacing
+  popViewport()# layout
+  popViewport()# spacing
 
-	# viewport for Bottom Names
-	pushViewport(viewport(width=unit(1, "npc") - unit(3,"lines"), height=unit(1, "npc") - unit(2, "lines")))
+  # viewport for Bottom Names
+  pushViewport(viewport(width=unit(1, "npc") - unit(3,"lines"), height=unit(1, "npc") - unit(2, "lines")))
 
-	pushViewport(viewport(layout = grid.layout(numCol, numCol, widths = rep(1,numCol), heights = rep(1,numCol) )))
+  pushViewport(viewport(layout = grid.layout(numCol, numCol, widths = rep(1,numCol), heights = rep(1,numCol) )))
 
 
-	# Bottom Side
-	for(i in 1:numCol){
-		grid.text(names(plotObj$data[,plotObj$columns])[i],0.5,0,just=c("centre","centre"), vp = vplayout(numCol, i))
-	}
+  # Bottom Side
+  for(i in 1:numCol){
+    grid.text(names(plotObj$data[,plotObj$columns])[i],0.5,0,just=c("centre","centre"), vp = vplayout(numCol, i))
+  }
 
-	popViewport() #layout
-	popViewport() #spacing
+  popViewport() #layout
+  popViewport() #spacing
 }
 
 ##############################################################  
@@ -699,23 +708,23 @@ if(!identical(plotObj$axisLabels,"internal")) {
 
 #####################  Plot Objects  #########################
 
-	pushViewport(v1) # labels on outside
-	pushViewport(v2) # layout of plots
+  pushViewport(v1) # labels on outside
+  pushViewport(v2) # layout of plots
   
   for(rowPos in 1:numCol){
     for(columnPos in 1:numCol){
       p <- getPlot(plotObj, rowPos, columnPos)
       if(!is_blank_plot(p)){
         
-      	pos <- columnPos + (rowPos - 1) * numCol
-      	type <- p$type
-      	subType <- p$subType
-      	if(plotObj$printInfo) {
+        pos <- columnPos + (rowPos - 1) * numCol
+        type <- p$type
+        subType <- p$subType
+        if(plotObj$printInfo) {
           cat("Pos #", pos)
           if(!is.null(type)) cat(": type = ", type)
           if(!is.null(subType)) cat(": subType = ", subType)
           cat("\n")
-      	}
+        }
           
         # hack because ggplot2 is annoying
         if(!is.null(subType)){
@@ -725,119 +734,132 @@ if(!identical(plotObj$axisLabels,"internal")) {
             p <- p + scale_x_continuous(NULL, labels="", breaks=1)
           } else if(subType == "ratio"){
             p <- p + 
-          		scale_x_continuous(
-          			NULL, 
-          			limits=c(1,length(p$x_names) + 1), 
-          			breaks=1:(length(p$x_names) + 1), 
-          			labels=c(p$x_names,""), 
-          			minor_breaks=FALSE
-          		) + 
-          		scale_y_continuous(
-          			NULL, 
-          			limits=c(1,length(p$y_names) + 1), 
-          			breaks=1:(length(p$y_names) + 1), 
-          			labels=c(p$y_names,""), 
-          			minor_breaks=FALSE
-          		)          		
+              scale_x_continuous(
+                NULL, 
+                limits=c(1,length(p$x_names) + 1), 
+                breaks=1:(length(p$x_names) + 1), 
+                labels=c(p$x_names,""), 
+                minor_breaks=FALSE
+              ) + 
+              scale_y_continuous(
+                NULL, 
+                limits=c(1,length(p$y_names) + 1), 
+                breaks=1:(length(p$y_names) + 1), 
+                labels=c(p$y_names,""), 
+                minor_breaks=FALSE
+              )              
 
           }
         }
+          
+        noTicks <- c("internal", "none")
+        removeTicks <- plotObj$axisLabels %in% noTicks
+        if( ! is.null(p$axisLabels)) {
+          removeTicks <- p$axisLabels %in% noTicks
+        }
+  
+        if( columnPos != 1 || removeTicks){
+          p <- p + opts(axis.text.y = theme_blank(), axis.title.y = theme_blank() )
+        }
 
-				removeTicks <- identical(plotObj$removeTicks, TRUE)
+        if( rowPos != numCol || removeTicks){
+          p <- p + opts(axis.text.x = theme_blank(), axis.title.x = theme_blank() )
+        }
 
-  			if( columnPos != 1 || removeTicks){
-  				p <- p + opts(axis.text.y = theme_blank(), axis.title.y = theme_blank() )
-  			}
-
-  			if( rowPos != numCol || removeTicks){
-  				p <- p + opts(axis.text.x = theme_blank(), axis.title.x = theme_blank() )
-  			}
-
-				if(removeTicks) {
-					p <- p + opts(
-						strip.background = theme_blank(),
-						strip.text.x = theme_blank(),
-						strip.text.y = theme_blank(),
+        if(removeTicks) {
+          p <- p + opts(
+            strip.background = theme_blank(),
+            strip.text.x = theme_blank(),
+            strip.text.y = theme_blank(),
                                     axis.ticks = theme_blank()
-					)
-		  		
-				}
-    		
-                # Adjusts for the blank space left by faceting, and manually
-                # sets the limits for numeric axes to 1% of the variable's
-                # range below the min and above the max.
-                if (identical(p$type,"combo")) {
-                  # Scale the numeric variable; the numeric variable is
-                  # mapped to the y variable for dot and box plots, but to the
-                  # x variable for the others
-                  if (p$subType %in% c("dot","box")) {
-                    ymin <- min(p$data[,as.character(p$mapping$y)])
-                    ymax <- max(p$data[,as.character(p$mapping$y)])
-                    p <- p + labs(x = NULL, y = NULL) +
-                      scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
-                  } 
-                  else {
-                    xmin <- min(p$data[,as.character(p$mapping$x)])
-                    xmax <- max(p$data[,as.character(p$mapping$x)])
-                    p <- p + labs(x = NULL, y = NULL) +
-                      scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
-                  }
-                  # Adjust for blank space left by faceting
-                  if (p$horizontal) {
-                    p <- p + opts(plot.margin = unit(c(0,-0.5,0,0), "lines"),
-                      legend.position = "none")
-                  } 
-                  else {
-                    p <- p + opts(plot.margin = unit(c(-0.5,0,0,0), "lines"),
-                      legend.position = "none")
-                  }                 
-                }
-                # Adjust for blank space left by faceting in faceted bar plot
-                else if (identical(p$subType,"facetbar")) {
-                  p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(c(0,-0.5,0,0), "lines"),
-                    legend.position = "none")
-                }
-                # Need to scale both variables for continuous plots
-                else if (identical(p$type,"continuous") && !identical(p$subType,"cor")) {
-                  xmin <- min(p$data[,as.character(p$mapping$x)])
-                  xmax <- max(p$data[,as.character(p$mapping$x)])
-                  ymin <- min(p$data[,as.character(p$mapping$y)])
-                  ymax <- max(p$data[,as.character(p$mapping$y)])
-                  p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0, 
-                    4), "lines"), legend.position = "none") +
-                    scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin))) +
-                    scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
-                }
-                # Scale the variable for numeric diagonal plots
-                else if (identical(p$type,"diag") && is.numeric(p$data[,as.character(p$mapping$x)])) {
-                  xmin <- min(p$data[,as.character(p$mapping$x)])
-                  xmax <- max(p$data[,as.character(p$mapping$x)])
-                  p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0,
-                    4), "lines"), legend.position = "none") +
-                    scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
-                }
-                else {
-                  p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0, 
-                    4), "lines"), legend.position = "none")
-                }
+          )
+          
+        }
+        
+        # Adjusts for the blank space left by faceting, and manually
+        # sets the limits for numeric axes to 1% of the variable's
+        # range below the min and above the max.
+        if (identical(p$type,"combo")) {
+          # Scale the numeric variable; the numeric variable is
+          # mapped to the y variable for dot and box plots, but to the
+          # x variable for the others
+          if (p$subType %in% c("dot","box")) {
+            ymin <- min(p$data[,as.character(p$mapping$y)])
+            ymax <- max(p$data[,as.character(p$mapping$y)])
+            p <- p + labs(x = NULL, y = NULL) +
+              scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
+          } 
+          else {
+            xmin <- min(p$data[,as.character(p$mapping$x)])
+            xmax <- max(p$data[,as.character(p$mapping$x)])
+            p <- p + labs(x = NULL, y = NULL) +
+              scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
+          }
+          # Adjust for blank space left by faceting
+          if (p$horizontal) {
+            p <- p + opts(plot.margin = unit(c(0,-0.5,0,0), "lines"))
+          } 
+          else {
+            p <- p + opts(plot.margin = unit(c(-0.5,0,0,0), "lines"))
+          }                 
+        }
+        # Adjust for blank space left by faceting in faceted bar plot
+        else if (identical(p$subType,"facetbar")) {
+          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(c(0,-0.5,0,0), "lines"))
+        }
+        # Need to scale both variables for continuous plots
+        else if (identical(p$type,"continuous") && !identical(p$subType,"cor")) {
+          xmin <- min(p$data[,as.character(p$mapping$x)])
+          xmax <- max(p$data[,as.character(p$mapping$x)])
+          ymin <- min(p$data[,as.character(p$mapping$y)])
+          ymax <- max(p$data[,as.character(p$mapping$y)])
+          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0, 
+            4), "lines")) +
+            scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin))) +
+            scale_y_continuous(limits=c(ymin-.01*(ymax-ymin),ymax+.01*(ymax-ymin)))
+        }
+        # Scale the variable for numeric diagonal plots
+        else if (identical(p$type,"diag") && is.numeric(p$data[,as.character(p$mapping$x)])) {
+          xmin <- min(p$data[,as.character(p$mapping$x)])
+          xmax <- max(p$data[,as.character(p$mapping$x)])
+          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0,
+            4), "lines")) +
+            scale_x_continuous(limits=c(xmin-.01*(xmax-xmin),xmax+.01*(xmax-xmin)))
+        }
+        else {
+          p <- p + labs(x = NULL, y = NULL) + opts(plot.margin = unit(rep(0, 
+            4), "lines"))
+        }
         
         
-  			grid.rect(
-  			  gp=gpar(fill="white",lty = "blank"),
-  			  vp = vplayout(rowPos, columnPos)
-    	  )
-    	  if(identical(plotObj$verbose, TRUE)) {
-					print(p, vp = vplayout(rowPos, columnPos))
-				} else {
-					suppressMessages(suppressWarnings(print(p, vp = vplayout(rowPos, columnPos))))
-				}
-      	
+        showLegend = FALSE
+        if (!is.null(plotObj$legends)) showLegend <- identical(plotObj$legends, TRUE)
+        if (showLegend == FALSE) {
+          if (!is.null(p$ggally$legend) && ! is.na(p$ggally$legend)) {
+            showLegend <- identical(p$ggally$legend, TRUE)
+          }
+        }
+        if (showLegend == FALSE) {
+          p <- p + opts(legend.position = "none")
+        }
+        
+        
+        grid.rect(
+          gp=gpar(fill="white",lty = "blank"),
+          vp = vplayout(rowPos, columnPos)
+        )
+        if(identical(plotObj$verbose, TRUE)) {
+          print(p, vp = vplayout(rowPos, columnPos))
+        } else {
+          suppressMessages(suppressWarnings(print(p, vp = vplayout(rowPos, columnPos))))
+        }
+        
       }# end plot alterations
     }# end cols
   }# end rows
   
-	popViewport() #layout
-	popViewport() #spacing
+  popViewport() #layout
+  popViewport() #spacing
 }
 
 #' Is Blank Plot?
@@ -845,8 +867,8 @@ if(!identical(plotObj$axisLabels,"internal")) {
 #'
 #' @keywords internal
 #' @examples
-#'  is_blank_plot(ggally_blank())
-#'  is_blank_plot(ggally_points(mtcars, aes_string(x = "disp", y = "hp")))
+#'  GGally:::is_blank_plot(ggally_blank())
+#'  GGally:::is_blank_plot(ggally_points(mtcars, aes_string(x = "disp", y = "hp")))
 #'
 is_blank_plot <- function(p){  
   if( !is.null(p$subType) && !is.null(p$type))
@@ -863,11 +885,11 @@ is_blank_plot <- function(p){
 #' @author Barret Schloerke \email{schloerke@@gmail.com}
 #' @return aes_string output
 #' @examples
-#' diamondMatrix <- ggpairs(	
+#' diamondMatrix <- ggpairs(  
 #'  diamonds,
-#'  columns = 1:3, 	
-#'  upper = list(points = "scatterplot", aes_string = aes_string(color = "clarity")), 	
-#'  lower = list(points = "scatterplot", aes_string = aes_string(color = "cut")), 	
+#'  columns = 1:3,   
+#'  upper = list(points = "scatterplot", aes_string = aes_string(color = "clarity")),   
+#'  lower = list(points = "scatterplot", aes_string = aes_string(color = "cut")),   
 #'  diag = "blank", 
 #'  color = "color", 
 #'  title = "Diamonds"
@@ -888,25 +910,26 @@ addAndOverwriteAes <- function(current, new)
 #' Replace the fill with the color and make color NULL
 #'
 #' @param current the current aesthetics
+#' @keywords internal
 mapping_color_fill <- function(current) {
-	currentNames <- names(current)
-	color <- c("color", "colour")
-	
-	if(any(color %in% currentNames) && "fill" %in% currentNames) {
-		# do nothing
-	} else if(any(color %in% currentNames)) {
-		# fill <- current[["fill" %in% currentNames]]
-		# col <- current[[color %in% currentNames]]
-		# current <- addAndOverwriteAes(current, aes_string(fill = col, color = NA))
-		current$fill <- current$colour
-		current$colour <- NULL		
-	}
-	
-	# if(!is.null(mapping$colour) && !is.null(mapping$fill)) {
-	# 	# do nothing
-	# } else if(!is.null(mapping$colour)) {
-	# }
-	current	
+  currentNames <- names(current)
+  color <- c("color", "colour")
+  
+  if(any(color %in% currentNames) && "fill" %in% currentNames) {
+    # do nothing
+  } else if(any(color %in% currentNames)) {
+    # fill <- current[["fill" %in% currentNames]]
+    # col <- current[[color %in% currentNames]]
+    # current <- addAndOverwriteAes(current, aes_string(fill = col, color = NA))
+    current$fill <- current$colour
+    current$colour <- NULL    
+  }
+  
+  # if(!is.null(mapping$colour) && !is.null(mapping$fill)) {
+  #   # do nothing
+  # } else if(!is.null(mapping$colour)) {
+  # }
+  current  
 }
 
 
